@@ -1,16 +1,14 @@
 # -*- coding: utf-8 -*-
 """Python lager brewed by a loguru"""
 import asyncio
-import atexit as _atexit
 import sys as _sys
 
 from functools import wraps
 from time import time
 from typing import Any, Callable, Dict, Optional, TypeVar, Union
 
-from loguru import _defaults
+from loguru import logger as logger
 from loguru._handler import Handler
-from loguru._logger import Core as _Core, Logger as _Logger
 
 from lager.const import LOG_LEVELS
 
@@ -86,12 +84,6 @@ try:
 except ModuleNotFoundError:
     pass
 
-logger = _Logger(_Core(), None, 0, False, False, False, False, True, None, {})
-if _defaults.LOGURU_AUTOINIT and _sys.stderr:  # type: ignore[truthy-bool]
-    logger.add(_sys.stderr)
-
-_atexit.register(logger.remove)
-
 # lager/logger aliases
 log = LOG = logger
 lager = LAGER = logger
