@@ -4,15 +4,14 @@ from typing import List, Optional, Set, Tuple, Union
 
 from lager.logging import intercept
 
-
-__all__ = ['FASTAPI_LOGGERS', 'fastapi_intercept']
+__all__ = ("FASTAPI_LOGGERS", "fastapi_intercept")
 
 FASTAPI_LOGGERS = [
-    'gunicorn',
-    'gunicorn.errors' 'uvicorn',
-    'uvicorn.error',
-    'fastapi',
-    'sqlalchemy',
+    "gunicorn",
+    "gunicorn.errors" "uvicorn",
+    "uvicorn.error",
+    "fastapi",
+    "sqlalchemy",
 ]
 
 
